@@ -21,11 +21,27 @@ def _collect_updates(version):
         if not isinstance(arguments, tuple):
             arguments = (arguments,)
 
-        collection.extend(arguments)
+        collection.extend(
+            [
+                a["components"]
+                if isinstance(a["components"], tuple)
+                else (a["components"],)
+                for a in arguments
+                if "components" in a
+            ]
+        )
 
     return collection
 
 
+def _mark_mixin_as_override(mixin):
+    if isinstance(mixin, str):
+        mixin = dict(name=mixin, overrides=True)
+    if isinstance(mixin, dict):
+        mixin["overrides"] = mixin.get("overrides", True)
+    return mixin
+
+
 def mapped_config(config):
     if isinstance(config, list):
         return [mapped_config(c) for c in config]
@@ -42,49 +58,6 @@ class ConfigInterface:
         self.default_class = default_class
         self.schema_validation = get_settings()["schema_validation"]
 
-    def _get_version(self, name, config):
-        # from yaml file
-        if name.endswith(".yaml") or name.endswith(".json"):
-            with open(name) as f:
-                return yaml.load(f, Loader=yaml.FullLoader)
-
-        # from mixin
-        if name.startswith("_") and name.endswith("_"):
-            try:
-                return copy.deepcopy(self.data["mixins"][name[1:-1]]["args"])
-            except KeyError:
-                raise KeyError(
-                    f"Mixin '{name}' not available.\n"
-                    f"Did you register it under 'mixins'?\n"
-                )
-
-        # from yaml string
-        if not name.startswith("~"):
-            return yaml.load(name, Loader=yaml.FullLoader)
-
-        # from local version
-        version = {}
-        path = name[1:].split(":")
-        level = config
-        try:
-            for key in path:
-                level = level["~" + key]
-                # extract config on this level
-                u = {
-                    k: copy.deepcopy(v)
-                    for k, v in level.items()
-                    if not k.startswith("~")
-                }
-                version = update_dict(version, u)
-            return version
-        except KeyError:
-            pass
-
-        raise KeyError(
-            f"Version '{name}' could not be found.\n"
-            f"Available versions: {[f for f in config.keys() if f.startswith('~')]}\n"
-        )
-
     @staticmethod
     def call_with_context(function, component, components=None, resources=None):
         signature = inspect.signature(function)
@@ -117,6 +90,40 @@ class ConfigInterface:
 
         return function(**payload)
 
+    def _get_version(self, name, config):
+        # from mixin
+        if name.startswith("_") and name.endswith("_"):
+            try:
+                return copy.deepcopy(self.data["mixins"][name[1:-1]]["args"])
+            except KeyError:
+                raise KeyError(
+                    f"Mixin '{name}' not available.\n"
+                    f"Did you register it under 'mixins'?\n"
+                )
+
+        # from local version
+        version = {}
+        path = name[1:].split(":")
+        level = config
+        try:
+            for key in path:
+                level = level["~" + key]
+                # extract config on this level
+                u = {
+                    k: copy.deepcopy(v)
+                    for k, v in level.items()
+                    if not k.startswith("~")
+                }
+                version = update_dict(version, u)
+            return version
+        except KeyError:
+            pass
+
+        raise KeyError(
+            f"Version '{name}' could not be found.\n"
+            f"Available versions: {[f for f in config.keys() if f.startswith('~')]}\n"
+        )
+
     def get_component(self, name, version=None, flags=None):
         if name is None:
             return None
@@ -148,6 +155,7 @@ class ConfigInterface:
         # introspection
         config["flags"]["NAME"] = name
         config["flags"]["MODULE"] = config["module"]
+        config["flags"]["VERSIONING"] = []
 
         # output redirection
         if "OUTPUT_REDIRECTION" not in config["flags"]:
@@ -170,9 +178,45 @@ class ConfigInterface:
         # un-alias
         origin = self.data["components"]["@"][name]
 
-        # mixins
-        for i, mixin in enumerate(parse_mixins(config["args"].get("_mixins_"))):
-            mixin_info = {"name": mixin["name"]}
+        # collect versions
+        config["versions"] = []
+        versions = copy.deepcopy(self.version)
+        if version is not None:
+            # merge local update to global updates
+            versions.append({"arguments": {"components": copy.deepcopy(version)}})
+        version_updates = _collect_updates(versions)
+
+        # parse mixins
+        default_mixins = config["args"].pop("_mixins_", None)
+
+        # check for default mixins overrides in version
+        mixins = None
+        for update in version_updates:
+            for k in update:
+                if not isinstance(k, dict):
+                    continue
+                override = k.pop("_mixins_", None)
+                if override is not None:
+                    mixins = override
+
+        if mixins is None:
+            mixins = default_mixins
+        else:
+            if default_mixins is None:
+                default_mixins = []
+            if not isinstance(default_mixins, (list, tuple)):
+                default_mixins = [default_mixins]
+            merged = []
+            for m in mixins:
+                if m == "^":
+                    merged.extend(default_mixins)
+                else:
+                    merged.append(_mark_mixin_as_override(m))
+            mixins = merged
+
+        mixin_specs = []
+        for mixin in parse_mixins(mixins):
+            mixin_spec = {"name": mixin["name"]}
 
             if mixin["name"].startswith("+."):
                 raise AttributeError(
@@ -194,7 +238,7 @@ class ConfigInterface:
                     )
 
                 # un-alias
-                mixin_info["origin"] = (
+                mixin_spec["origin"] = (
                     "+."
                     + vendor
                     + "."
@@ -208,7 +252,7 @@ class ConfigInterface:
                                 mixin["vendor"] + "." + mixin["name"]
                             ]
                         )
-                        mixin_info["origin"] = (
+                        mixin_spec["origin"] = (
                             "+."
                             + mixin["vendor"]
                             + "."
@@ -223,7 +267,7 @@ class ConfigInterface:
                 else:
                     try:
                         mixin_args = copy.deepcopy(self.data["mixins"][mixin["name"]])
-                        mixin_info["origin"] = self.data["mixins"]["@"].get(
+                        mixin_spec["origin"] = self.data["mixins"]["@"].get(
                             mixin["name"]
                         )
                     except KeyError:
@@ -235,35 +279,27 @@ class ConfigInterface:
                             )
                         )
 
-            # the mixin config can be overwritten by the local config so we update the mixin arg and write it back
-            config["args"] = update_dict(mixin_args["args"], config["args"], copy=True)
+            if mixin["overrides"]:
+                # mixin overrides config
+                config["args"] = update_dict(config["args"], mixin_args["args"])
+            else:
+                # config overrides mixin
+                config["args"] = update_dict(mixin_args["args"], config["args"])
 
-            # write information
-            config["args"]["_mixins_"][i] = mixin_info
+            mixin_specs.append(mixin_spec)
+
+        config["args"]["_mixins_"] = mixin_specs
 
         # parse updates
-
-        # merge local update to global updates
-        config["versions"] = []
-        versions = copy.deepcopy(self.version)
-        if version is not None:
-            versions.append({"arguments": {"components": copy.deepcopy(version)}})
-
         version = {}
-        for updates in _collect_updates(versions):
-            update = updates.get("components", None)
-            if update is None:
-                continue
-
-            if not isinstance(update, tuple):
-                update = (update,)
-
+        for update in version_updates:
             for k in update:
                 if k is None:
                     continue
-                # load arguments from machinable.yaml
                 if isinstance(k, str):
                     config["versions"].append(k)
+                    if k.startswith("~"):
+                        config["flags"]["VERSIONING"].append(k[1:])
                     k = self._get_version(k, config["args"])
                 elif isinstance(k, dict):
                     # evaluate computed properties
@@ -278,15 +314,20 @@ class ConfigInterface:
                 # merge with version
                 version = update_dict(version, k)
 
-        config["args"] = update_dict(
-            config["args"], version, preserve_schema=self.schema_validation
-        )
+        try:
+            config["args"] = update_dict(
+                config["args"], version, preserve_schema=self.schema_validation
+            )
+        except KeyError as e:
+            raise KeyError(
+                "Trying to override a key that is not present in the machinable.yaml: "
+                f"{getattr(e, 'message', str(e))!s} "
+                "To ignore this error, disable the schema_validation setting."
+            ) from e
 
-        # remove unused versions
+        # remove versions
         config["args"] = {
-            k: v if not k.startswith("~") else ":"
-            for k, v in config["args"].items()
-            if not k.startswith("~") or k in config["versions"]
+            k: v for k, v in config["args"].items() if not k.startswith("~")
         }
 
         return config
@@ -304,7 +345,9 @@ class ConfigInterface:
         for c in components:
             subcomponent = ExperimentComponent.create(c)
             component_config = self.get_component(
-                subcomponent.name, subcomponent.version, subcomponent.flags
+                subcomponent.name,
+                subcomponent.version,
+                subcomponent.flags,
             )
             if component_config is not None:
                 components_config.append(component_config)
