@@ -289,12 +289,6 @@ class Component(Mixin):
         """Event interface"""
         return self._events
 
-    def __getattr__(self, name):
-        # Mixins and dynamic attributes are set during construction; this helps suppressing IDE warnings
-        raise AttributeError(
-            f"{self.__class__.__name__} component has no attribute {name}"
-        )
-
     def dispatch(
         self,
         components_config: List[Dict],
@@ -490,8 +484,7 @@ class Component(Mixin):
         self.on_after_destroy()
 
     def refresh_status(self, log_errors=False):
-        """Updates the status.json file with a heartbeat at the current time
-        """
+        """Updates the status.json file with a heartbeat at the current time"""
         if not self.storage:
             return False
 
@@ -569,8 +562,8 @@ class Component(Mixin):
 
     def serialize(self):
         return {
-            "config": self.config.toDict(evaluate=True, with_hidden=False),
-            "flags": self.flags.toDict(evaluate=True),
+            "config": self.config.as_dict(evaluate=True, discard_hidden=True),
+            "flags": self.flags.as_dict(evaluate=True),
         }
 
     # life cycle
@@ -656,8 +649,7 @@ class Component(Mixin):
         pass
 
     def on_init_storage(self, storage_config: Dict):
-        """Lifecycle event triggered at write initialisation
-        """
+        """Lifecycle event triggered at write initialisation"""
         pass
 
     def on_after_create(self):
@@ -678,8 +670,7 @@ class Component(Mixin):
         pass
 
     def on_before_execute_iteration(self, iteration: int):
-        """Lifecycle event triggered before an execution iteration
-        """
+        """Lifecycle event triggered before an execution iteration"""
         pass
 
     def on_execute_iteration(self, iteration: int):
@@ -756,7 +747,10 @@ class FunctionalComponent:
         apply_seed(self.node["flags"].get("SEED"))
         self.node["flags"]["ACTOR"] = actor_config
         components = [
-            {"config": copy.deepcopy(c["args"]), "flags": copy.deepcopy(c["flags"]),}
+            {
+                "config": copy.deepcopy(c["args"]),
+                "flags": copy.deepcopy(c["flags"]),
+            }
             for c in components_config
         ]
 
