@@ -170,6 +170,17 @@ class Execution(Jsonable):
 
         return self
 
+    def set_directory(self, directory):
+        if directory is not None:
+            if not isinstance(directory, str):
+                raise ValueError("Directory must be a string")
+            if directory[0] == "/":
+                raise ValueError("Directory must be relative")
+
+        self.storage.config["directory"] = directory
+
+        return self
+
     def set_engine(self, engine):
         if engine is None:
             engine = get_settings()["default_engine"]
@@ -187,6 +198,9 @@ class Execution(Jsonable):
         return self
 
     def set_project(self, project):
+        if project is None:
+            project = get_settings()["default_project"]
+
         self.project = Project.create(project)
 
         return self
@@ -470,7 +484,7 @@ class Execution(Jsonable):
 
         Registration.get().on_submit(self, is_submitted)
 
-        return self.engine.submit(self)
+        return self.engine.dispatch(self)
 
     def set_result(self, result, index=None, echo=True):
         if index is None:
@@ -569,13 +583,13 @@ class Execution(Jsonable):
                 "config.json",
                 {
                     "component": {
-                        "args": nd.config.toDict(evaluate=True),
-                        "flags": nd.flags.toDict(evaluate=True),
+                        "args": nd.config.as_dict(evaluate=True),
+                        "flags": nd.flags.as_dict(evaluate=True),
                     },
                     "components": [
                         {
-                            "args": comps[i].config.toDict(evaluate=True),
-                            "flags": comps[i].flags.toDict(evaluate=True),
+                            "args": comps[i].config.as_dict(evaluate=True),
+                            "flags": comps[i].flags.as_dict(evaluate=True),
                             "class": get_class_name(components[i]["class"]),
                         }
                         for i in range(len(comps))
@@ -648,13 +662,16 @@ class Execution(Jsonable):
             self.set_schedule()
 
         msg(
-            f"\n{self.submission_id}\n------", color="header",
+            f"\n{self.submission_id}\n------",
+            color="header",
         )
         msg(
-            f"{repr(self.experiment)}", color="blue",
+            f"{repr(self.experiment)}",
+            color="blue",
         )
         msg(
-            f"{repr(self.storage)}", color="blue",
+            f"{repr(self.storage)}",
+            color="blue",
         )
         msg(f"{repr(self.engine)}", color="blue")
         msg(f"{repr(self.index)}", color="blue")
@@ -671,6 +688,8 @@ class Execution(Jsonable):
                     "SUBMISSION_ID",
                     "SEED",
                     "COMPONENT_ID",
+                    "VERSIONING",
+                    "LINEAGE",
                     "REPEAT_SEED",
                     "REPEAT_TOTAL",
                     "REPEAT_NUMBER",
