@@ -26,6 +26,8 @@ class SqlBaseModel(BaseModel):
         if isinstance(database, str):
             database = dataset.connect(database)
         self._db = database
+        if filesystem_model is None:
+            filesystem_model = SubmissionComponentModel.get()
         self._filesystem_model = filesystem_model
         if isinstance(url, Submission):
             self.url = url.model.url
@@ -38,16 +40,15 @@ class SqlBaseModel(BaseModel):
                 self._data = url
                 url = url["url"]
             self.url = url
-            self.submission_id = self.filesystem_model.submission_id
-            self.component_id = self.filesystem_model.component_id
+            parsed = parse_storage_url(self.url)
+            self.submission_id = parsed["submission_id"]
+            self.component_id = parsed["component_id"]
 
     def submission_model(self, url):
         return SqlSubmissionModel(url, self._db)
 
     def submission_component_model(self, url):
-        return SqlSubmissionComponentModel(
-            url, self._db, filesystem_model=SubmissionComponentModel.get()
-        )
+        return SqlSubmissionComponentModel(url, self._db)
 
 
 class SqlSubmissionModel(SqlBaseModel, FileSystemSubmissionModel):
@@ -95,7 +96,7 @@ class SqlSubmissionModel(SqlBaseModel, FileSystemSubmissionModel):
         return Submission(self)
 
 
-class SqlSubmissionComponentModel(SqlBaseModel, FileSystemSubmissionModel):
+class SqlSubmissionComponentModel(SqlBaseModel, FileSystemSubmissionComponentModel):
     @property
     def filesystem_model(self):
         if self._filesystem_model is None:
@@ -155,7 +156,7 @@ class SqlIndex(Index):
         ]
 
     def _find_all(self):
-        table = self._table("experiments")
+        table = self._table("submissions")
         return table.all()
 
     def _table(self, name):
@@ -166,7 +167,7 @@ class SqlIndex(Index):
         if self._migrated is True:
             return
 
-        table = self._db["experiments"]
+        table = self._db["submissions"]
         table.create_column("url", self._db.types.string)
         table.create_column("submission_id", self._db.types.string)
         table.create_column("started_at", self._db.types.datetime)
@@ -177,6 +178,7 @@ class SqlIndex(Index):
         table.create_column("host_json", self._db.types.json)
         table.create_column("label", self._db.types.text)
         table.create_column("comments", self._db.types.text)
+        table.create_column("meta", self._db.types.json)
 
         table = self._db["components"]
         table.create_column("url", self._db.types.string)
@@ -188,6 +190,7 @@ class SqlIndex(Index):
         table.create_column("components_json", self._db.types.json)
         table.create_column("state_json", self._db.types.json)
         table.create_column("host_json", self._db.types.json)
+        table.create_column("meta", self._db.types.json)
 
         self._migrated = True
 
