@@ -7,21 +7,20 @@ from starlette.middleware import Middleware
 from starlette.middleware.cors import CORSMiddleware
 from starlette.routing import Route
 
-from .filesystem import storage_resolver
-from .graphql import mutation, query, scalar_types, subscription
+from .filesystem import filesystem_resolver
+from .graphql import directives, mutation, query, scalar_types, subscription
 
 dir_path = os.path.dirname(os.path.realpath(__file__))
 schema = make_executable_schema(
     load_schema_from_path(os.path.join(dir_path, "graphql/schema/")),
     [*scalar_types, query, mutation, subscription],
+    directives=directives,
 )
 
 
 graphql = GraphQL(schema, keepalive=True)
 
-routes = [
-    Route("/filesystem/storage/{url:path}/{filename:path}", endpoint=storage_resolver)
-]
+routes = [Route("/filesystem/{url:path}/{filename:path}", endpoint=filesystem_resolver)]
 
 middleware = [
     Middleware(
