@@ -1,8 +1,8 @@
 import os
 import shutil
+from zipfile import ZipFile
 
-import pytest
-
+from machinable import execute
 from machinable.project import Project
 
 
@@ -113,17 +113,70 @@ def test_parse_config():
     for k, v in config["components"].items():
         if k.find("@") != -1:
             continue
+        if v["module"] in ["test_project.component", "test_project.scope.section"]:
+            continue
         v["class"].load(instantiate=False)
 
 
+def test_lineage_recording():
+    test_project = Project("./test_project")
+    config = test_project.parse_config()
+
+    def _linage(component):
+        return config["components"][component]["flags"]["LINEAGE"]
+
+    assert _linage("childexp") == ["thenode"]
+    assert _linage("inherit") == ["+.fooba.experiments.start", "start_parent"]
+    assert _linage("test_dependent") == ["base", "grandfurther"]
+
+
 def test_project_code_backup(helpers):
+    # create symlinks
+    p = "./test_project/code_backup"
+    os.makedirs(p + "/project/catch_me", exist_ok=True)
+    with open(p + "/project/catch_me/if-you-can.txt", "w") as f:
+        f.write("test")
+    with open(p + "/extern/ignore_me.txt", "w") as f:
+        f.write("please")
+    try:
+        os.symlink(
+            os.path.abspath(p + "/project/catch_me"),
+            p + "/project/link",
+            target_is_directory=True,
+        )
+    except FileExistsError:
+        pass
+    try:
+        os.symlink(
+            os.path.abspath(p + "/extern"),
+            p + "/project/external_link",
+            target_is_directory=True,
+        )
+    except FileExistsError:
+        pass
+
+    # test backup
     helpers.tmp_directory("code_backup")
     target_file = "./_test_data/code_backup/code.zip"
     if os.path.isfile(target_file):
         os.remove(target_file)
-    project = Project("./test_project")
-    project.backup_source_code(target_file)
-    assert os.path.isfile(target_file)
+    project = Project(p + "/project")
+    # manual
+    assert project.backup_source_code(target_file) is True
+    archive = ZipFile(target_file)
+    assert set(map(lambda f: f.filename, archive.filelist)) == {
+        "machinable.yaml",
+        "main.py",
+        "dummy.py",
+        "link/",
+        "link/if-you-can.txt",
+        "external_link/",
+        "external_link/ignore_me.txt",
+        "external_link/come-find-me.txt",
+    }
+    # during execution
+    e = execute("dummy", storage="./_test_data/code_backup/symlinks", project=project)
+    assert os.path.isfile(e.storage.get_local_directory("code.zip"))
 
 
 def test_project_get_code_version():
